summaryrefslogtreecommitdiffstats
path: root/net/base/net_log.h
diff options
context:
space:
mode:
authordavidben@chromium.org <davidben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-12 23:07:02 +0000
committerdavidben@chromium.org <davidben@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-03-12 23:07:02 +0000
commitc47c03736dd5f52be91b5fe10e08a35c27249ac8 (patch)
tree1a2fadb44a295e0608ffe1516d59fa05330a1ad9 /net/base/net_log.h
parent24c3938589c45f9425adb2d57c5bde24f06a0f3a (diff)
downloadchromium_src-c47c03736dd5f52be91b5fe10e08a35c27249ac8.zip
chromium_src-c47c03736dd5f52be91b5fe10e08a35c27249ac8.tar.gz
chromium_src-c47c03736dd5f52be91b5fe10e08a35c27249ac8.tar.bz2
Remove NetLog::LOG_BASIC.
It's only used in test code. Preparatory CL to introduce a LOG_STRIP_PRIVATE_DATA log level, so we don't have to break the ordering of levels. BUG=349502 Review URL: https://codereview.chromium.org/196203002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@256690 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'net/base/net_log.h')
-rw-r--r--net/base/net_log.h20
1 files changed, 5 insertions, 15 deletions
diff --git a/net/base/net_log.h b/net/base/net_log.h
index 901362a..e8e7598 100644
--- a/net/base/net_log.h
+++ b/net/base/net_log.h
@@ -78,10 +78,6 @@ class NET_EXPORT NetLog {
// parameters for bytes sent/received events.
LOG_ALL_BUT_BYTES,
- // Only log events which are cheap, and don't consume much memory. This is
- // the default value for observers.
- LOG_BASIC,
-
// Don't log any events.
LOG_NONE,
};
@@ -233,11 +229,6 @@ class NET_EXPORT NetLog {
// Adds an observer and sets its log level. The observer must not be
// watching any NetLog, including this one, when this is called.
//
- // Typical observers should specify LOG_BASIC.
- //
- // Observers that need to see the full granularity of events can specify
- // LOG_ALL_BUT_BYTES. However, doing so will have performance consequences.
- //
// NetLog implementations must call NetLog::OnAddObserver to update the
// observer's internal state.
void AddThreadSafeObserver(ThreadSafeObserver* observer, LogLevel log_level);
@@ -279,10 +270,9 @@ class NET_EXPORT NetLog {
// be logged. This is only the case when |log_level| is LOG_ALL.
static bool IsLoggingBytes(LogLevel log_level);
- // Returns true if |log_level| indicates that all events should be logged,
- // including frequently occuring ones that may impact performances.
- // This is the case when |log_level| is LOG_ALL or LOG_ALL_BUT_BYTES.
- static bool IsLoggingAllEvents(LogLevel log_level);
+ // Returns true if |log_level| indicates that events should be logged. This is
+ // the case when |log_level| is anything other than LOG_NONE.
+ static bool IsLogging(LogLevel log_level);
// Creates a ParametersCallback that encapsulates a single integer.
// Warning: |name| must remain valid for the life of the callback.
@@ -391,8 +381,8 @@ class NET_EXPORT BoundNetLog {
// Shortcut for NetLog::IsLoggingBytes(this->GetLogLevel()).
bool IsLoggingBytes() const;
- // Shortcut for NetLog::IsLoggingAllEvents(this->GetLogLevel()).
- bool IsLoggingAllEvents() const;
+ // Shortcut for NetLog::IsLogging(this->GetLogLevel()).
+ bool IsLogging() const;
// Helper to create a BoundNetLog given a NetLog and a SourceType. Takes care
// of creating a unique source ID, and handles the case of NULL net_log.